@@ -3,8 +3,7 @@ var ExtCommonUtils = {
 
 	debug : false,
 
-	initialized : false,
-	destructed  : false,
+	activated : false,
 
 	content      : 'chrome://ctxextensions/content/',
 	locale       : 'chrome://ctxextensions/locale/',
@@ -1385,11 +1384,12 @@ var ExtCommonUtils = {
 
 
 		var range = targetWindow.document.createRange();
-		try {
+		if (selection.anchorNode == selection.focusNode ||
+			selection.anchorNode.compareDocumentPosition(selection.focusNode) & Node.DOCUMENT_POSITION_FOLLOWING) {
 			range.setStart(selection.anchorNode, selection.anchorOffset);
 			range.setEnd(selection.focusNode, selection.focusOffset);
 		}
-		catch(e) {
+		else {
 			range.setStart(selection.focusNode, selection.focusOffset);
 			range.setEnd(selection.anchorNode, selection.anchorOffset);
 		}
@@ -1547,7 +1547,10 @@ var ExtCommonUtils = {
 
 		var children = aContainer.childNodes;
 		for (i = children.length-1; i > -1; i--)
-			if ('extGenerated' in children[i] && children[i].extGenerated)
+			if (
+				('extGenerated' in children[i] && children[i].extGenerated) ||
+				children[i].getAttribute('extGenerated') == 'true'
+				)
 				aContainer.removeChild(children[i]);
 
 		var node, data;
@@ -1563,6 +1566,7 @@ var ExtCommonUtils = {
 
 			aContainer.lastChild.extGenerated = true;
 		}
+//dump(aContainer.getAttribute('ext-datasource')+' / '+obj.length+'('+aContainer.childNodes.length+')\n');
 	},
   
 	readCSSFor : function(aTextboxOrID) 
@@ -1715,6 +1719,9 @@ var ExtCommonUtils = {
   
 	init : function() 
 	{
+		if (this.activated) return;
+		this.activated = true;
+
 		var i;
 		var nullPointer;
 
@@ -1740,11 +1747,17 @@ var ExtCommonUtils = {
 		var dsource_uri = this.datasourceURI;
 		var nodes   = document.getElementsByAttribute('datasources', 'chrome://ctxextensions/content/ctxextensions.rdf'),
 			dsource = this.RDF.GetDataSource(dsource_uri),
+			lclst;
+		try {
 			lclst   = this.RDF.GetDataSource('rdf:localstore');
+		}
+		catch(e) {
+		}
 		for (i = 0; i < nodes.length; i++)
 		{
 			nodes[i].database.AddDataSource(dsource);
-			nodes[i].database.RemoveDataSource(lclst);
+			if (lclst)
+				nodes[i].database.RemoveDataSource(lclst);
 			if (nsIXULTemplateBuilderAvailable) {
 				nodes[i].builder.rebuild();
 			}
@@ -1752,9 +1765,6 @@ var ExtCommonUtils = {
 				this.rebuildFromTemplate(nodes[i]);
 			}
 		}
-
-
-		this.initialized = true;
 	},
 	loadPrefs : function()
 	{
@@ -1805,14 +1815,14 @@ var ExtCommonUtils = {
 // initialize
 window.addEventListener('load', function()
 {
-	if (ExtCommonUtils.initialized) return;
+	if (ExtCommonUtils.activated) return;
 
 	ExtCommonUtils.init();
 },
 false);
 window.addEventListener('load', function()
 {
-	if (ExtCommonUtils.initialized) return;
+	if (ExtCommonUtils.activated) return;
 
 	ExtCommonUtils.init();
 },
